=======
History
=======


0.1.0 (2020-05-06)
------------------

* First release on PyPI. Data for the Life-cycle process models include: LF, WTE, Composting, AD, SS_MRF, reprocessing and Collection.
